aboutsummaryrefslogtreecommitdiffstats
path: root/java/src
diff options
context:
space:
mode:
authorTadashi G. Takaoka <takaoka@google.com>2012-02-08 00:04:16 -0800
committerAndroid (Google) Code Review <android-gerrit@google.com>2012-02-08 00:04:16 -0800
commit614cb02a9183841ec8ea76615c879e1da439cc10 (patch)
tree3dc6c71dc9bdc8a59bfd109b7c015bb3483c6468 /java/src
parent1bd1cd19c0bf1367a0355b1f46caa9979e976aca (diff)
parent2affaf91a04d63e0994102299816014a8bbe11e1 (diff)
downloadlatinime-614cb02a9183841ec8ea76615c879e1da439cc10.tar.gz
latinime-614cb02a9183841ec8ea76615c879e1da439cc10.tar.xz
latinime-614cb02a9183841ec8ea76615c879e1da439cc10.zip
Merge "Rename mini keyboard to more keys keyboard"
Diffstat (limited to 'java/src')
-rw-r--r--java/src/com/android/inputmethod/keyboard/Key.java2
-rw-r--r--java/src/com/android/inputmethod/keyboard/Keyboard.java10
-rw-r--r--java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java28
-rw-r--r--java/src/com/android/inputmethod/keyboard/MoreKeysKeyboard.java (renamed from java/src/com/android/inputmethod/keyboard/MiniKeyboard.java)53
-rw-r--r--java/src/com/android/inputmethod/keyboard/MoreKeysKeyboardView.java (renamed from java/src/com/android/inputmethod/keyboard/MiniKeyboardView.java)28
-rw-r--r--java/src/com/android/inputmethod/keyboard/ProximityInfo.java2
6 files changed, 62 insertions, 61 deletions
diff --git a/java/src/com/android/inputmethod/keyboard/Key.java b/java/src/com/android/inputmethod/keyboard/Key.java
index 6eaa606db..5656c38b4 100644
--- a/java/src/com/android/inputmethod/keyboard/Key.java
+++ b/java/src/com/android/inputmethod/keyboard/Key.java
@@ -245,7 +245,7 @@ public class Key {
mActionFlags = actionFlags;
mMoreKeys = moreKeys;
mMaxMoreKeysColumn = style.getInt(keyAttr,
- R.styleable.Keyboard_Key_maxMoreKeysColumn, params.mMaxMiniKeyboardColumn);
+ R.styleable.Keyboard_Key_maxMoreKeysColumn, params.mMaxMoreKeysKeyboardColumn);
mLabel = adjustCaseOfStringForKeyboardId(style.getString(keyAttr,
R.styleable.Keyboard_Key_keyLabel), preserveCase, params.mId);
diff --git a/java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java b/java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java
index 870c7cb25..88a41579d 100644
--- a/java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java
+++ b/java/src/com/android/inputmethod/keyboard/LatinKeyboardView.java
@@ -92,13 +92,13 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
private final Drawable mAutoCorrectionSpacebarLedIcon;
private static final int SPACE_LED_LENGTH_PERCENT = 80;
- // Mini keyboard
+ // More keys keyboard
private PopupWindow mMoreKeysWindow;
private MoreKeysPanel mMoreKeysPanel;
private int mMoreKeysPanelPointerTrackerId;
private final WeakHashMap<Key, MoreKeysPanel> mMoreKeysPanelCache =
new WeakHashMap<Key, MoreKeysPanel>();
- private final boolean mConfigShowMiniKeyboardAtTouchedPoint;
+ private final boolean mConfigShowMoreKeysKeyboardAtTouchedPoint;
private final PointerTrackerParams mPointerTrackerParams;
private final boolean mIsSpacebarTriggeringPopupByLongPress;
@@ -137,7 +137,7 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
break;
case MSG_LONGPRESS_KEY:
if (tracker != null) {
- keyboardView.openMiniKeyboardIfRequired(tracker.getKey(), tracker);
+ keyboardView.openMoreKeysKeyboardIfRequired(tracker.getKey(), tracker);
} else {
KeyboardSwitcher.getInstance().onLongPressTimeout(msg.arg1);
}
@@ -338,8 +338,8 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
R.styleable.LatinKeyboardView_keyHysteresisDistance, 0);
mKeyDetector = new KeyDetector(keyHysteresisDistance);
mKeyTimerHandler = new KeyTimerHandler(this, keyTimerParams);
- mConfigShowMiniKeyboardAtTouchedPoint = a.getBoolean(
- R.styleable.LatinKeyboardView_showMiniKeyboardAtTouchedPoint, false);
+ mConfigShowMoreKeysKeyboardAtTouchedPoint = a.getBoolean(
+ R.styleable.LatinKeyboardView_showMoreKeysKeyboardAtTouchedPoint, false);
a.recycle();
PointerTracker.setParameters(mPointerTrackerParams);
@@ -435,7 +435,7 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
super.cancelAllMessages();
}
- private boolean openMiniKeyboardIfRequired(Key parentKey, PointerTracker tracker) {
+ private boolean openMoreKeysKeyboardIfRequired(Key parentKey, PointerTracker tracker) {
// Check if we have a popup layout specified first.
if (mMoreKeysLayout == 0) {
return false;
@@ -458,19 +458,19 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
if (container == null)
throw new NullPointerException();
- final MiniKeyboardView miniKeyboardView =
- (MiniKeyboardView)container.findViewById(R.id.mini_keyboard_view);
+ final MoreKeysKeyboardView moreKeysKeyboardView =
+ (MoreKeysKeyboardView)container.findViewById(R.id.more_keys_keyboard_view);
final Keyboard parentKeyboard = getKeyboard();
- final Keyboard miniKeyboard = new MiniKeyboard.Builder(
+ final Keyboard moreKeysKeyboard = new MoreKeysKeyboard.Builder(
this, parentKeyboard.mMoreKeysTemplate, parentKey, parentKeyboard).build();
- miniKeyboardView.setKeyboard(miniKeyboard);
+ moreKeysKeyboardView.setKeyboard(moreKeysKeyboard);
container.measure(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
- return miniKeyboardView;
+ return moreKeysKeyboardView;
}
/**
- * Called when a key is long pressed. By default this will open mini keyboard associated
+ * Called when a key is long pressed. By default this will open more keys keyboard associated
* with this key.
* @param parentKey the key that was long pressed
* @param tracker the pointer tracker which pressed the parent key
@@ -524,13 +524,13 @@ public class LatinKeyboardView extends KeyboardView implements PointerTracker.Ke
if (mMoreKeysWindow == null) {
mMoreKeysWindow = new PopupWindow(getContext());
mMoreKeysWindow.setBackgroundDrawable(null);
- mMoreKeysWindow.setAnimationStyle(R.style.MiniKeyboardAnimation);
+ mMoreKeysWindow.setAnimationStyle(R.style.MoreKeysKeyboardAnimation);
}
mMoreKeysPanel = moreKeysPanel;
mMoreKeysPanelPointerTrackerId = tracker.mPointerId;
final Keyboard keyboard = getKeyboard();
- final int pointX = (mConfigShowMiniKeyboardAtTouchedPoint) ? tracker.getLastX()
+ final int pointX = (mConfigShowMoreKeysKeyboardAtTouchedPoint) ? tracker.getLastX()
: parentKey.mX + parentKey.mWidth / 2;
final int pointY = parentKey.mY - keyboard.mVerticalGap;
moreKeysPanel.showMoreKeysPanel(
diff --git a/java/src/com/android/inputmethod/keyboard/ProximityInfo.java b/java/src/com/android/inputmethod/keyboard/ProximityInfo.java
index 2d1a0083d..41e7ef435 100644
--- a/java/src/com/android/inputmethod/keyboard/ProximityInfo.java
+++ b/java/src/com/android/inputmethod/keyboard/ProximityInfo.java
@@ -59,7 +59,7 @@ public class ProximityInfo {
mKeyHeight = keyHeight;
mGridNeighbors = new Key[mGridSize][];
if (minWidth == 0 || height == 0) {
- // No proximity required. Keyboard might be mini keyboard.
+ // No proximity required. Keyboard might be more keys keyboard.
return;
}
computeNearestNeighbors(keyWidth, keys, touchPositionCorrection, additionalProximityChars);
diff --git a/java/src/com/android/inputmethod/keyboard/Keyboard.java b/java/src/com/android/inputmethod/keyboard/Keyboard.java
index 10e0a5b01..cb6a54569 100644
--- a/java/src/com/android/inputmethod/keyboard/Keyboard.java
+++ b/java/src/com/android/inputmethod/keyboard/Keyboard.java
@@ -121,8 +121,8 @@ public class Keyboard {
/** More keys keyboard template */
public final int mMoreKeysTemplate;
- /** Maximum column for mini keyboard */
- public final int mMaxMiniKeyboardColumn;
+ /** Maximum column for more keys keyboard */
+ public final int mMaxMoreKeysKeyboardColumn;
/** List of keys and icons in this keyboard */
public final Set<Key> mKeys;
@@ -143,7 +143,7 @@ public class Keyboard {
mMostCommonKeyHeight = params.mMostCommonKeyHeight;
mMostCommonKeyWidth = params.mMostCommonKeyWidth;
mMoreKeysTemplate = params.mMoreKeysTemplate;
- mMaxMiniKeyboardColumn = params.mMaxMiniKeyboardColumn;
+ mMaxMoreKeysKeyboardColumn = params.mMaxMoreKeysKeyboardColumn;
mTopPadding = params.mTopPadding;
mVerticalGap = params.mVerticalGap;
@@ -226,7 +226,7 @@ public class Keyboard {
public int mVerticalGap;
public int mMoreKeysTemplate;
- public int mMaxMiniKeyboardColumn;
+ public int mMaxMoreKeysKeyboardColumn;
public int GRID_WIDTH;
public int GRID_HEIGHT;
@@ -770,7 +770,7 @@ public class Keyboard {
params.mMoreKeysTemplate = keyboardAttr.getResourceId(
R.styleable.Keyboard_moreKeysTemplate, 0);
- params.mMaxMiniKeyboardColumn = keyAttr.getInt(
+ params.mMaxMoreKeysKeyboardColumn = keyAttr.getInt(
R.styleable.Keyboard_Key_maxMoreKeysColumn, 5);
params.mIconsSet.loadIcons(keyboardAttr);
diff --git a/java/src/com/android/inputmethod/keyboard/MiniKeyboard.java b/java/src/com/android/inputmethod/keyboard/MoreKeysKeyboard.java
index 4648da1c1..83155f719 100644
--- a/java/src/com/android/inputmethod/keyboard/MiniKeyboard.java
+++ b/java/src/com/android/inputmethod/keyboard/MoreKeysKeyboard.java
@@ -21,10 +21,10 @@ import android.graphics.Paint;
import com.android.inputmethod.keyboard.internal.KeySpecParser;
import com.android.inputmethod.latin.R;
-public class MiniKeyboard extends Keyboard {
+public class MoreKeysKeyboard extends Keyboard {
private final int mDefaultKeyCoordX;
- private MiniKeyboard(Builder.MiniKeyboardParams params) {
+ private MoreKeysKeyboard(Builder.MoreKeysKeyboardParams params) {
super(params);
mDefaultKeyCoordX = params.getDefaultKeyCoordX() + params.mDefaultKeyWidth / 2;
}
@@ -33,21 +33,21 @@ public class MiniKeyboard extends Keyboard {
return mDefaultKeyCoordX;
}
- public static class Builder extends Keyboard.Builder<Builder.MiniKeyboardParams> {
+ public static class Builder extends Keyboard.Builder<Builder.MoreKeysKeyboardParams> {
private final String[] mMoreKeys;
- public static class MiniKeyboardParams extends Keyboard.Params {
+ public static class MoreKeysKeyboardParams extends Keyboard.Params {
/* package */int mTopRowAdjustment;
public int mNumRows;
public int mNumColumns;
public int mLeftKeys;
public int mRightKeys; // includes default key.
- public MiniKeyboardParams() {
+ public MoreKeysKeyboardParams() {
super();
}
/* package for test */MiniKeyboardParams(int numKeys, int maxColumns, int keyWidth,
int rowHeight, int coordXInParent, int parentKeyboardWidth) {
super();
setParameters(numKeys, maxColumns, keyWidth, rowHeight, coordXInParent,
@@ -55,21 +55,21 @@ public class MiniKeyboard extends Keyboard {
}
/**
* Set keyboard parameters of mini keyboard.
*
* @param numKeys number of keys in this mini keyboard.
* @param maxColumns number of maximum columns of this mini keyboard.
* @param keyWidth mini keyboard key width in pixel, including horizontal gap.
* @param rowHeight mini keyboard row height in pixel, including vertical gap.
* @param coordXInParent coordinate x of the popup key in parent keyboard.
* @param parentKeyboardWidth parent keyboard width in pixel.
*/
public void setParameters(int numKeys, int maxColumns, int keyWidth, int rowHeight,
int coordXInParent, int parentKeyboardWidth) {
if (parentKeyboardWidth / keyWidth < maxColumns) {
throw new IllegalArgumentException(
- "Keyboard is too small to hold mini keyboard: " + parentKeyboardWidth
- + " " + keyWidth + " " + maxColumns);
+ "Keyboard is too small to hold more keys keyboard: "
+ + parentKeyboardWidth + " " + keyWidth + " " + maxColumns);
}
mDefaultKeyWidth = keyWidth;
mDefaultRowHeight = rowHeight;
@@ -95,14 +95,14 @@ public class MiniKeyboard extends Keyboard {
leftKeys = numLeftKeys;
rightKeys = numRightKeys;
}
// Shift right if the left edge of mini keyboard is on the edge of parent keyboard
// unless the parent key is on the left edge.
if (leftKeys * keyWidth >= coordXInParent && leftKeys > 0) {
leftKeys--;
rightKeys++;
}
// Shift left if the right edge of mini keyboard is on the edge of parent keyboard
// unless the parent key is on the right edge.
if (rightKeys * keyWidth + coordXInParent >= parentKeyboardWidth && rightKeys > 1) {
leftKeys++;
rightKeys--;
@@ -204,10 +204,10 @@ public class MiniKeyboard extends Keyboard {
}
public Builder(KeyboardView view, int xmlId, Key parentKey, Keyboard parentKeyboard) {
- super(view.getContext(), new MiniKeyboardParams());
+ super(view.getContext(), new MoreKeysKeyboardParams());
load(xmlId, parentKeyboard.mId);
// TODO: Mini keyboard's vertical gap is currently calculated heuristically.
// Should revise the algorithm.
mParams.mVerticalGap = parentKeyboard.mVerticalGap / 2;
mMoreKeys = parentKey.mMoreKeys;
@@ -215,8 +215,9 @@ public class MiniKeyboard extends Keyboard {
final int previewWidth = view.mKeyPreviewDrawParams.mPreviewBackgroundWidth;
final int previewHeight = view.mKeyPreviewDrawParams.mPreviewBackgroundHeight;
final int width, height;
// Use pre-computed width and height if these values are available and mini keyboard
// has only one key to mitigate visual flicker between key preview and mini keyboard.
if (view.isKeyPreviewPopupEnabled() && mMoreKeys.length == 1 && previewWidth > 0
&& previewHeight > 0) {
width = previewWidth;
@@ -231,7 +232,7 @@ public class MiniKeyboard extends Keyboard {
private static int getMaxKeyWidth(KeyboardView view, String[] moreKeys, int minKeyWidth) {
final int padding = (int) view.getContext().getResources()
- .getDimension(R.dimen.mini_keyboard_key_horizontal_padding);
+ .getDimension(R.dimen.more_keys_keyboard_key_horizontal_padding);
Paint paint = null;
int maxWidth = minKeyWidth;
for (String moreKeySpec : moreKeys) {
@@ -252,8 +253,8 @@ public class MiniKeyboard extends Keyboard {
}
@Override
- public MiniKeyboard build() {
- final MiniKeyboardParams params = mParams;
+ public MoreKeysKeyboard build() {
+ final MoreKeysKeyboardParams params = mParams;
for (int n = 0; n < mMoreKeys.length; n++) {
final String moreKeySpec = mMoreKeys[n];
final int row = n / params.mNumColumns;
@@ -262,7 +263,7 @@ public class MiniKeyboard extends Keyboard {
params.markAsEdgeKey(key, row);
params.onAddKey(key);
}
- return new MiniKeyboard(params);
+ return new MoreKeysKeyboard(params);
}
}
}
@@ -33,21 +33,21 @@ public class MiniKeyboard extends Keyboard {
super();
}
- /* package for test */MiniKeyboardParams(int numKeys, int maxColumns, int keyWidth,
+ /* package for test */MoreKeysKeyboardParams(int numKeys, int maxColumns, int keyWidth,
int rowHeight, int coordXInParent, int parentKeyboardWidth) {
super();
@@ -55,21 +55,21 @@ public class MiniKeyboard extends Keyboard {
}
/**
- * Set keyboard parameters of mini keyboard.
+ * Set keyboard parameters of more keys keyboard.
*
@@ -55,21 +55,21 @@ public class MiniKeyboard extends Keyboard {
*
- * @param numKeys number of keys in this mini keyboard.
- * @param maxColumns number of maximum columns of this mini keyboard.
- * @param keyWidth mini keyboard key width in pixel, including horizontal gap.
- * @param rowHeight mini keyboard row height in pixel, including vertical gap.
- * @param coordXInParent coordinate x of the popup key in parent keyboard.
+ * @param numKeys number of keys in this more keys keyboard.
+ * @param maxColumns number of maximum columns of this more keys keyboard.
+ * @param keyWidth more keys keyboard key width in pixel, including horizontal gap.
+ * @param rowHeight more keys keyboard row height in pixel, including vertical gap.
+ * @param coordXInParent coordinate x of the key preview in parent keyboard.
* @param parentKeyboardWidth parent keyboard width in pixel.
*/
@@ -95,14 +95,14 @@ public class MiniKeyboard extends Keyboard {
rightKeys = numRightKeys;
}
- // Shift right if the left edge of mini keyboard is on the edge of parent keyboard
- // unless the parent key is on the left edge.
+ // Shift right if the left edge of more keys keyboard is on the edge of parent
+ // keyboard unless the parent key is on the left edge.
if (leftKeys * keyWidth >= coordXInParent && leftKeys > 0) {
leftKeys--;
@@ -95,14 +95,14 @@ public class MiniKeyboard extends Keyboard {
rightKeys++;
}
- // Shift left if the right edge of mini keyboard is on the edge of parent keyboard
- // unless the parent key is on the right edge.
+ // Shift left if the right edge of more keys keyboard is on the edge of parent
+ // keyboard unless the parent key is on the right edge.
if (rightKeys * keyWidth + coordXInParent >= parentKeyboardWidth && rightKeys > 1) {
leftKeys++;
@@ -204,10 +204,10 @@ public class MiniKeyboard extends Keyboard {
load(xmlId, parentKeyboard.mId);
- // TODO: Mini keyboard's vertical gap is currently calculated heuristically.
+ // TODO: More keys keyboard's vertical gap is currently calculated heuristically.
// Should revise the algorithm.
mParams.mVerticalGap = parentKeyboard.mVerticalGap / 2;
@@ -215,8 +215,9 @@ public class MiniKeyboard extends Keyboard {
final int previewHeight = view.mKeyPreviewDrawParams.mPreviewBackgroundHeight;
final int width, height;
- // Use pre-computed width and height if these values are available and mini keyboard
- // has only one key to mitigate visual flicker between key preview and mini keyboard.
+ // Use pre-computed width and height if these values are available and more keys
+ // keyboard has only one key to mitigate visual flicker between key preview and more
+ // keys keyboard.
if (view.isKeyPreviewPopupEnabled() && mMoreKeys.length == 1 && previewWidth > 0
&& previewHeight > 0) {
diff --git a/java/src/com/android/inputmethod/keyboard/MiniKeyboardView.java b/java/src/com/android/inputmethod/keyboard/MoreKeysKeyboardView.java
index 72d5b6889..b030dd95a 100644
--- a/java/src/com/android/inputmethod/keyboard/MiniKeyboardView.java
+++ b/java/src/com/android/inputmethod/keyboard/MoreKeysKeyboardView.java
@@ -28,10 +28,10 @@ import com.android.inputmethod.keyboard.PointerTracker.TimerProxy;
import com.android.inputmethod.latin.R;
/**
* A view that renders a virtual {@link MiniKeyboard}. It handles rendering of keys and detecting
* key presses and touch movements.
*/
-public class MiniKeyboardView extends KeyboardView implements MoreKeysPanel {
+public class MoreKeysKeyboardView extends KeyboardView implements MoreKeysPanel {
private final int[] mCoordinates = new int[2];
private final KeyDetector mKeyDetector;
@@ -43,7 +43,7 @@ public class MiniKeyboardView extends KeyboardView implements MoreKeysPanel {
private static final TimerProxy EMPTY_TIMER_PROXY = new TimerProxy.Adapter();
- private final KeyboardActionListener mMiniKeyboardListener =
+ private final KeyboardActionListener mMoreKeysKeyboardListener =
new KeyboardActionListener.Adapter() {
@Override
public void onCodeInput(int primaryCode, int[] keyCodes, int x, int y) {
@@ -71,16 +71,16 @@ public class MiniKeyboardView extends KeyboardView implements MoreKeysPanel {
}
};
- public MiniKeyboardView(Context context, AttributeSet attrs) {
- this(context, attrs, R.attr.miniKeyboardViewStyle);
+ public MoreKeysKeyboardView(Context context, AttributeSet attrs) {
+ this(context, attrs, R.attr.moreKeysKeyboardViewStyle);
}
- public MiniKeyboardView(Context context, AttributeSet attrs, int defStyle) {
+ public MoreKeysKeyboardView(Context context, AttributeSet attrs, int defStyle) {
super(context, attrs, defStyle);
final Resources res = context.getResources();
mKeyDetector = new MoreKeysDetector(
- res.getDimension(R.dimen.mini_keyboard_slide_allowance));
+ res.getDimension(R.dimen.more_keys_keyboard_slide_allowance));
setKeyPreviewPopupEnabled(false, 0);
}
@@ -110,7 +110,7 @@ public class MiniKeyboardView extends KeyboardView implements MoreKeysPanel {
@Override
public KeyboardActionListener getKeyboardActionListener() {
- return mMiniKeyboardListener;
+ return mMoreKeysKeyboardListener;
}
@Override
@@ -125,7 +125,7 @@ public class MiniKeyboardView extends KeyboardView implements MoreKeysPanel {
@Override
public void setKeyPreviewPopupEnabled(boolean previewEnabled, int delay) {
- // Mini keyboard needs no pop-up key preview displayed, so we pass always false with a
+ // More keys keyboard needs no pop-up key preview displayed, so we pass always false with a
// delay of 0. The delay does not matter actually since the popup is not shown anyway.
super.setKeyPreviewPopupEnabled(false, 0);
}
@@ -136,13 +136,13 @@ public class MiniKeyboardView extends KeyboardView implements MoreKeysPanel {
mController = controller;
mListener = listener;
final View container = (View)getParent();
- final MiniKeyboard miniKeyboard = (MiniKeyboard)getKeyboard();
+ final MoreKeysKeyboard moreKeysKeyboard = (MoreKeysKeyboard)getKeyboard();
parentView.getLocationInWindow(mCoordinates);
- final int miniKeyboardLeft = pointX - miniKeyboard.getDefaultCoordX()
+ final int moreKeysKeyboardLeft = pointX - moreKeysKeyboard.getDefaultCoordX()
+ parentView.getPaddingLeft();
- final int x = wrapUp(Math.max(0, Math.min(miniKeyboardLeft,
- parentView.getWidth() - miniKeyboard.mOccupiedWidth))
+ final int x = wrapUp(Math.max(0, Math.min(moreKeysKeyboardLeft,
+ parentView.getWidth() - moreKeysKeyboard.mOccupiedWidth))
- container.getPaddingLeft() + mCoordinates[0],
container.getMeasuredWidth(), 0, parentView.getWidth());
final int y = pointY
@@ -28,10 +28,10 @@ import com.android.inputmethod.keyboard.PointerTracker.TimerProxy;
import com.android.inputmethod.latin.R;
/**
- * A view that renders a virtual {@link MiniKeyboard}. It handles rendering of keys and detecting
- * key presses and touch movements.
+ * A view that renders a virtual {@link MoreKeysKeyboard}. It handles rendering of keys and
+ * detecting key presses and touch movements.
*/